package com.clx.performance.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.clx.order.enums.DeleteStatusEnum;
import com.clx.performance.dao.PlatformAccountConfigDao;
import com.clx.performance.enums.PerformanceResultEnum;
import com.clx.performance.model.PlatformAccountConfig;
import com.clx.performance.param.pc.carrier.PagePlatformAccountConfigParam;
import com.clx.performance.param.pc.carrier.SavePlatformAccountConfigParam;
import com.clx.performance.service.PlatformAccountConfigService;
import com.clx.performance.struct.PlatformAccountConfigStruct;
import com.clx.performance.vo.pc.carrier.settle.*;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author jiangwenye
 * Date 2024-01-25
 * Time 09:43
 */
@Slf4j
@Service
@AllArgsConstructor
public class PlatformAccountConfigServiceImpl implements PlatformAccountConfigService {

    private final PlatformAccountConfigDao platformAccountConfigDao;

    private final PlatformAccountConfigStruct platformAccountConfigStruct;

    @Override
    public IPage<CarrierPagePlatformAccountConfigVO> pagePlatformAccountConfig(PagePlatformAccountConfigParam param) {
        IPage<PlatformAccountConfig> page =  platformAccountConfigDao.pagePlatformAccountConfig(param);
        List<CarrierPagePlatformAccountConfigVO> list = platformAccountConfigStruct.convertToVOList(page.getRecords());
        return new Page<CarrierPagePlatformAccountConfigVO>().setRecords(list).setTotal(page.getTotal()).setPages(page.getPages());
    }

    @Override
    public CarrierPagePlatformAccountConfigVO getPlatformAccountConfigDetail(Integer id) {
        //结算单详情
        PlatformAccountConfig platformAccountConfig =platformAccountConfigDao.getEntityByKey(id).orElseThrow(PerformanceResultEnum.DATA_NOT_FIND);
        CarrierPagePlatformAccountConfigVO detail = platformAccountConfigStruct.convertToDetail(platformAccountConfig);
        return detail;
    }

    @Override
    public void deletePlatformAccountConfig(Integer id) {
        platformAccountConfigDao.deletePlatformAccountConfig(id);
    }

    @Override
    public void updatePlatformAccountConfig(SavePlatformAccountConfigParam param) {
        PlatformAccountConfig config = new PlatformAccountConfig();
        config.setId(param.getId());
        config.setBusinessType(param.getBusinessType());
        config.setOwnerType(param.getOwnerType());
        config.setInvoiceType(param.getInvoiceType());
        config.setInvoiceCompanyId(param.getInvoiceCompanyId());
        config.setInvoiceCompanyName(param.getInvoiceCompanyName());
        config.setConfigRange(param.getConfigRange());
        config.setCompanyName(param.getCompanyName());
        config.setBankName(param.getBankName());
        config.setOpenBank(param.getOpenBank());
        config.setBankCode(param.getBankCode());
        config.setBankCardNo(param.getBankCardNo());
        platformAccountConfigDao.updatePlatformAccountConfig(config);
    }

    @Override
    public void savePlatformAccountConfig(SavePlatformAccountConfigParam param){
        PlatformAccountConfig config = new PlatformAccountConfig();
        config.setBusinessType(param.getBusinessType());
        config.setOwnerType(param.getOwnerType());
        config.setInvoiceType(param.getInvoiceType());
        config.setInvoiceCompanyId(param.getInvoiceCompanyId());
        config.setInvoiceCompanyName(param.getInvoiceCompanyName());
        config.setConfigRange(param.getConfigRange());
        config.setCompanyName(param.getCompanyName());
        config.setBankName(param.getBankName());
        config.setOpenBank(param.getOpenBank());
        config.setBankCode(param.getBankCode());
        config.setBankCardNo(param.getBankCardNo());
        config.setDeleteStatus(DeleteStatusEnum.YES.getCode());
        platformAccountConfigDao.saveEntity(config);
    }


}
